#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.model.response import Response


class PkgCommonResponse(Response):
    def __init__(self):
        super(PkgCommonResponse, self).__init__()
        self._pkg_id = None
        self._pkg_edit_id = None

    @property
    def pkg_id(self):
        return self._pkg_id

    @pkg_id.setter
    def pkg_id(self, pkg_id):
        self._pkg_id = pkg_id

    @property
    def pkg_edit_id(self):
        return self._pkg_edit_id

    @pkg_edit_id.setter
    def pkg_edit_id(self, pkg_edit_id):
        self._pkg_edit_id = pkg_edit_id



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class PkgProduct:
    def __init__(self):
        self._name = None
        self._default_lang = None
        self._dev_product_id = None
        self._status = None
        self._localized_data = None
        self._validity_unit = None
        self._validity_num = None
        self._deeplink_url = None
        self._need_delivery = None
        self._price_list = None

    @property
    def name(self):
        """
        :return: mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        会员包关联商品名称
        :param name:
        :return:
        """
        self._name = name

    @property
    def default_lang(self):
        """
        缺省语言
        :return:
        """
        return self._default_lang

    @default_lang.setter
    def default_lang(self, default_lang):
        self._default_lang = default_lang

    @property
    def dev_product_id(self):
        """
        :return: mixed
        """
        return self._dev_product_id

    @dev_product_id.setter
    def dev_product_id(self, dev_product_id):
        """
        会员包关联商品ID
        :param dev_product_id:
        :return:
        """
        self._dev_product_id = dev_product_id

    @property
    def localized_data(self):
        """
        :return: mixed
        """
        return self._localized_data

    @localized_data.setter
    def localized_data(self, localized_data):
        """
        会员包版本商品本地化多语言数据，即需要随会员包版本进行审核的商品本地化多语言数据
        :param localized_data:
        :return:
        """
        self._localized_data = localized_data

    @property
    def validity_unit(self):
        """
        :return: mixed
        """
        return self._validity_unit

    @validity_unit.setter
    def validity_unit(self, validity_unit):
        """
        会员包订购关系有效期长度单位
        :param validity_unit:
        :return:
        """
        self._validity_unit = validity_unit

    @property
    def status(self):
        """
        :return: mixed
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        会员包商品状态
        :param status:
        :return:
        """
        self._status = status

    @property
    def validity_num(self):
        """
        :return: mixed
        """
        return self._validity_num

    @validity_num.setter
    def validity_num(self, validity_num):
        """
        会员包订购关系有效期长度
        :param validity_num:
        :return:
        """
        self._validity_num = validity_num

    @property
    def deeplink_url(self):
        """
        :return: mixed
        """
        return self._deeplink_url

    @deeplink_url.setter
    def deeplink_url(self, deeplink_url):
        """
        从教育中心App跳转到您的App的DeepLink链接
        :param deeplink_url:
        :return:
        """
        self._deeplink_url = deeplink_url

    @property
    def need_delivery(self):
        """
        :return: mixed
        """
        return self._need_delivery

    @need_delivery.setter
    def need_delivery(self, need_delivery):
        """
        商品购买后是否需要邮寄材料
        :param need_delivery:
        :return:
        """
        self._need_delivery = need_delivery

    @property
    def price_list(self):
        """
        :return:mixed
        """
        return self._price_list

    @price_list.setter
    def price_list(self, price_list):
        """
        多个国家的会员包商品定价
        :param price_list:
        :return:
        """
        self._price_list = price_list



#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from setuptools import setup, find_packages

setup(
    name='edukit-sdk',
    author='Huawei',
    version='11.4.2.200',
    url='https://developer.huawei.com/consumer/cn/doc/development/'
        'AppGallery-connect-Guides/edukit-introduction-0000001050822201',
    author_email='opencapability@huawei.com',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'numpy==1.19.5', 'opencv-contrib-python==4.2.0.34',
        'opencv-python==4.4.0.46'
    ]
)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from typing import Optional


class EduKitClient:
    def __init__(self,
                 client_id: Optional[str] = None,
                 client_secret: Optional[str] = None,
                 grant_type="client_credentials"):
        self.client_id = client_id
        self.client_secret = client_secret
        self.grant_type = grant_type



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class UpdateMediaLocalizedData:
    def __init__(self):
        self._media_type = None
        self._ordinal = None
        self._meida_id = None
        self._frame_id = None
        self._file_name = None
        self._sha256 = None
        self._media_len = None
        self._size = None
        self._width = None
        self._height = None

    @property
    def media_type(self):
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        self._media_type = media_type

    @property
    def ordinal(self):
        return self._ordinal

    @ordinal.setter
    def ordinal(self, ordinal):
        self._ordinal = ordinal

    @property
    def meida_id(self):
        return self._meida_id

    @meida_id.setter
    def meida_id(self, meida_id):
        self._meida_id = meida_id

    @property
    def frame_id(self):
        return self._frame_id

    @frame_id.setter
    def frame_id(self, frame_id):
        self._frame_id = frame_id

    @property
    def file_name(self):
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        self._file_name = file_name

    @property
    def sha256(self):
        return self.__sha256

    @sha256.setter
    def sha256(self, sha256):
        self._sha256 = sha256

    @property
    def height(self):
        return self._height

    @height.setter
    def height(self, height):
        self._height = height

    @property
    def media_len(self):
        return self._media_len

    @media_len.setter
    def media_len(self, media_len):
        self._media_len = media_len

    @property
    def size(self):
        return self._size

    @size.setter
    def size(self, size):
        self._size = size

    @property
    def width(self):
        return self._width

    @width.setter
    def width(self, width):
        self._width = width



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.lesson.impl.lesson_handler import LessonHandler
from edukit_sdk.edukit.lesson.model.lesson_edit import LessonEdit
from edukit_sdk.edukit.lesson.resp.lesson_update_response import \
    LessonUpdateResponse


class LessonUpdateRequest:
    def __init__(self,
                 lesson_edit: LessonEdit,
                 credential_list):
        self._lesson_edit = lesson_edit
        self._force_create_new_edit = True
        self._lesson_handler = LessonHandler(
            EduKitRequestSender(credential_list))
        self._lesson_edit_id = None

    def update_lesson(self):
        rsp = LessonUpdateResponse()
        if Helpers.has_empty_param([
                self._lesson_edit.course_id, self._lesson_edit.course_edit_id,
                self._lesson_edit.lesson
        ]):
            logging.error(
                'CourseId or CourseEditId or Lesson can not be null '
                'when create lesson.'
            )
            rsp.result = Helpers.build_error_result(
                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
            return rsp
        if not self._lesson_edit_id:
            self._lesson_edit_id = self._lesson_edit.lesson_edit_id

        if not self._lesson_edit_id:
            result = self._lesson_handler.create_lesson_new_edit(
                self._lesson_edit, self._force_create_new_edit)
            if result and result.result and result.result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                logging.error(
                    'Create lesson new edit version failed and code:%s '
                    'message:%s'
                    % (result.result.result_code, result.result.result_desc))
                rsp.result = result.result
                return rsp
            self._lesson_edit_id = result.lesson_edit_id

        rsp.lesson_id = self._lesson_edit.lesson.lesson_id
        rsp.lesson_edit_id = self._lesson_edit_id

        return self._lesson_handler.update_lesson_data(
            self._lesson_edit.course_id, self._lesson_edit.course_edit_id,
            self._lesson_edit.lesson.lesson_id, self._lesson_edit_id,
            self._lesson_edit.lesson, rsp)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class EduKitException(Exception):
    def __init__(self, message, code=0):
        self._message = message
        self._code = code

    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, message):
        self._message = message

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, code):
        self._code = code



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.model.response import Response


class UpdatePkgProductResponse(Response):
    def __init__(self):
        super(UpdatePkgProductResponse, self).__init__()
        self._details = None

    @property
    def details(self):
        return self._details

    @details.setter
    def details(self, details):
        self._details = details



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.package.impl.pkg_handler import PkgHandler


class PkgManageRequest:
    def __init__(self, pkg_id, action, removal_reason, credential_list):
        self._pkg_id = pkg_id
        self._action = action
        self._removal_reason = removal_reason
        self._pkg_handler = PkgHandler(EduKitRequestSender(credential_list))

    def manage(self):
        return self._pkg_handler.manage(self._pkg_id, self._action,
                                        self._removal_reason)



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class Lesson:
    def __init__(self):
        self._lesson_id = None
        self._meta_data = None
        self._multi_lang_localized_data_list = None
        self._language_list_to_delete = None
        self._catalogue_id = None
        self._progress_callback = None

    @property
    def lesson_id(self):
        """
        :return:mixed
        """
        return self._lesson_id

    @lesson_id.setter
    def lesson_id(self, lesson_id):
        """
        设置章节ID。创建章节时由教育中心生成，用于唯一标识一个章节，调用getLessonId()获取。
        :param lesson_id:
        """
        self._lesson_id = lesson_id

    @property
    def meta_data(self):
        """
        :return:mixed
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """
        设置章节元数据。
        :param meta_data:
        """
        self._meta_data = meta_data

    @property
    def multi_lang_localized_data_list(self):
        """
        :return:mixed
        """
        return self._multi_lang_localized_data_list

    @multi_lang_localized_data_list.setter
    def multi_lang_localized_data_list(self, multi_lang_localized_data_list):
        """
        设置章节本地化多语言数据列表。
        :param multi_lang_localized_data_list:
        """
        self._multi_lang_localized_data_list = multi_lang_localized_data_list

    @property
    def language_list_to_delete(self):
        """
        :return:mixed
        """
        return self._language_list_to_delete

    @language_list_to_delete.setter
    def language_list_to_delete(self, language_list_to_delete):
        """
        设置需要删除的多语言列表。
        整体删除指定语言的所有多语言数据。如仅需要删除或更新特定语言下的特定字段，可构造LessonMultiLanguageData对象。
        简体中文及默认语言的多语言数据不允许删除。
        语言代码由BCP-47定义，如简体中文为"zh-CN"，区分大小写（语言标识使用小写字母；区域名称使用大写字母）。
        :param language_list_to_delete :
        """
        self._language_list_to_delete = language_list_to_delete

    @property
    def progress_callback(self):
        """
        :return:mixed
        """
        return self._progress_callback

    @progress_callback.setter
    def progress_callback(self, progress_callback):
        """
        设置文件上传进度回调函数。
        :param progress_callback:
        """
        self._progress_callback = progress_callback

    @property
    def catalogue_id(self):
        """
        :return:mixed
        """
        return self._catalogue_id

    @catalogue_id.setter
    def catalogue_id(self, catalogue_id):
        """
        章节关联的目录ID
        :param catalogue_id:
        """
        self._catalogue_id = catalogue_id



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.course.model.course_edit_meta_data import \
    CourseEditMetaData


class CourseMetaData:
    """课程元数据类"""
    def __init__(self):
        self._meta_data = None
        self._country_codes = None

    @property
    def meta_data(self):
        """
        :return: mixed
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data: CourseEditMetaData):
        """
        课程版本编辑元数据
        :param meta_data:
        :return:
        """
        self._meta_data = meta_data

    @property
    def country_codes(self):
        """
        :return: mixed
        """
        return self._country_codes

    @country_codes.setter
    def country_codes(self, country_codes):
        """
        * 课程可上架国家/地区列表，说明如下：
         * 将国家/地区加入此列表，表示允许教育中心在此国家/地区分发此课程
         * 此列表中必须包含中国大陆地区(代码为"CN")，其它国家/地区可选(当前教育中心业务仅覆盖中国大陆地区)
         * 首次提交后需要更新时，必须将更新后的可上架国家/地区列表全量提交，不能只提交变化的部分
         * 国家代码使用ISO-3166-1定义的两位字符形式代码，如中国为"CN"。代码需使用大写字符。
        :param country_codes:
        :return:
        """
        self._country_codes = country_codes

    def to_bytes(self):
        """
        将对象转为JSON类型的字节
        :return:bytes
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class ClientConstant:
    FILE_SIZE = 'fileSize'
    FILE_SHA256 = 'fileSha256'
    RESOURCE_TYPE = 'resourseType'
    FILE_NAME = 'fileName'
    FILE = 'file'
    FILE_TYPE = 'fileType'
    PUBLIC_FILE = 'publicFile'
    PART_MAXSIZE = 'PART_MAXSIZE'
    TMP_UPLOAD_URL = 'tmpUploadUrl'
    UPLOAD_HEADERS = 'uploadHeaders'
    UPLOAD_METHOD = 'uploadMethod'
    FILE_ID = 'fileId'
    FILE_PARTS = 'fileParts'
    PART_OBJECT_ID = 'partObjectId'
    MATERIAL_URL = 'materialUrl'
    GOOGLE_GENERATION = 'googleGeneration'
    X_GOOGLE_GENERATION = 'X-Google-Generation'
    MULTI_PART_FLAG = 'multiPartFlag'
    UTF_8 = 'utf-8'
    RB = "rb"
    MAX_PAER_SIZE = 'maxPartSize'
    _HEADERS = '_headers'
    E_TAG = 'ETag'
    SERVER_DOMAIN = 'SERVER_DOMAIN'
    SDK_NAME = 'SDK_NAME'
    SDK_VERSION = 'SDK_VERSION'
    REQUESTING = 'Requesting'
    TUTOR_PORTRAIT = 'TUTOR_PORTRAIT'
    ERROR_MESSAGE = 'error_message'



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import os

from edukit_sdk.edukit.common.constant.error_constant import ErrorConstant
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.helpers.helpers import Helpers


class FileUploadRequest:
    def __init__(
        self,
        path,
        file_type=None,
        resource_type='-1',
        public_file='False',
    ):
        if not os.path.exists(path):
            raise EduKitException(ErrorConstant.FILE_NOT_EXISTS.format(path))
        self._path = path
        self._file_name = Helpers.get_file_base_name(
            path)  # 因为接口中filename带扩展名，故在此使用get_file_base_name()
        self._file_extension = Helpers.get_file_extension(path)
        self._file_size = Helpers.get_file_size(path)
        self._sha256 = Helpers.get_sha256(path)
        self._file_type = Helpers.get_mime(
            path) if not file_type else file_type
        self._resource_type = resource_type
        self._public_file = public_file

    @property
    def path(self):
        return self._path

    @property
    def file_name(self):
        return self._file_name

    @property
    def file_extension(self):
        return self._file_extension

    @property
    def file_size(self):
        return self._file_size

    @property
    def sha256(self):
        return self._sha256

    @property
    def file_type(self):
        return self._file_type

    @property
    def resource_type(self):
        return self._resource_type

    @property
    def public_file(self):
        return self._public_file



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class TeacherCommitRequest:
    def __init__(self):
        self._teacher_id = None,
        self._edit_id = None,

    @property
    def teacher_id(self):
        return self._teacher_id

    @teacher_id.setter
    def teacher_id(self, teacher_id):
        self._teacher_id = teacher_id

    @property
    def edit_id(self):
        return self._edit_id

    @edit_id.setter
    def edit_id(self, edit_id):
        self._edit_id = edit_id

    def to_json_string(self):
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.model.response import Response


class LearningHandler:
    def __init__(self, request_sender):
        self.__request_sender = request_sender

    def report_unitary_course_learning(self, user_id, course_id, user_id_type,
                                       unitary_course_learning_info):
        logging.info(
            "Call reportUnitaryCourseLearning interface start, courseId: %s",
            course_id)
        response = Response()
        try:
            url = ApiConstant.REPORT_UNITARY_COURSE_LEARNING.format(
                user_id, course_id, user_id_type)
            http_common_response = HttpCommonResponse(
                self.__request_sender.put(
                    url=url,
                    body=unitary_course_learning_info.to_json_string()))
            response.result = Helpers.build_result(
                http_common_response.get_rsp())
        except EduKitException as e:
            logging.error(
                u"Call reportUnitaryCourseLearning interface "
                u"failed. ErrorMessage: %s",
                str(e))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        logging.info(
            "Call reportUnitaryCourseLearning interface end, courseId: %s",
            course_id)
        return response

    def report_series_course_learning(self, user_id, course_id, user_id_type,
                                      lesson_id, series_course_learning_info):
        logging.info(
            "Call reportSeriesCourseLearning interface start, "
            "courseId: %s, lessonId: %s"
            % (course_id, lesson_id))
        response = Response()
        try:
            url = ApiConstant.REPORT_SERIES_COURSE_LEARNING.format(
                user_id, course_id, lesson_id, user_id_type)
            http_common_response = HttpCommonResponse(
                self.__request_sender.put(
                    url=url,
                    body=series_course_learning_info.to_json_string()))
            response.result = Helpers.build_result(
                http_common_response.get_rsp())
        except EduKitException as e:
            logging.error(
                u"Call reportUnitaryCourseLearning interface failed. "
                u"ErrorMessage: %s",
                str(e))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        logging.info(
            "Call reportUnitaryCourseLearning interface end, courseId: %s",
            course_id)
        return response
